"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkPopupPosition = exports.removeItemFromEditableCells = exports.getCellEditorDispatchHandler = exports.addItemToEditableCells = exports.getEditableCell = exports.isEditableCell = exports.getNewRowEditableCells = void 0;
var actionCreators_1 = require("../actionCreators");
var const_1 = require("../const");
var enums_1 = require("../enums");
var ArrayUtils_1 = require("./ArrayUtils");
var getNewRowEditableCells = function (editableCells) {
    return editableCells && editableCells.filter(function (c) { return c.rowKeyValue === const_1.newRowId; });
};
exports.getNewRowEditableCells = getNewRowEditableCells;
var isEditableCell = function (editingMode, column, rowEditableCells) {
    if (column.isEditable !== undefined) {
        return column.isEditable;
    }
    return !!rowEditableCells.find(function (c) { return c.columnKey === column.key; });
};
exports.isEditableCell = isEditableCell;
var getEditableCell = function (column, rowEditableCells) {
    if (column.isEditable === false) {
        return undefined;
    }
    return rowEditableCells.find(function (c) { return c.columnKey === column.key; });
};
exports.getEditableCell = getEditableCell;
var addItemToEditableCells = function (item, editableCells) {
    return (0, ArrayUtils_1.getCopyOfArrayAndAddItem)(item, editableCells);
};
exports.addItemToEditableCells = addItemToEditableCells;
var getCellEditorDispatchHandler = function (dispatch) {
    return function (action) {
        if (action.type === enums_1.ActionType.UpdateEditorValue) {
            dispatch((0, actionCreators_1.updateCellValue)(action.rowKeyValue, action.columnKey, action.value));
        }
        else {
            dispatch(action);
        }
    };
};
exports.getCellEditorDispatchHandler = getCellEditorDispatchHandler;
var removeItemFromEditableCells = function (item, editableCells) {
    return editableCells.filter(function (c) { return c.columnKey !== item.columnKey || c.rowKeyValue !== item.rowKeyValue; });
};
exports.removeItemFromEditableCells = removeItemFromEditableCells;
var checkPopupPosition = function (column, refToElement, dispatch) {
    var _a, _b, _c, _d;
    if (refToElement.current && column.isHeaderFilterPopupShown) {
        var newPopupPosition = {
            x: refToElement.current.offsetLeft + ((_a = refToElement.current.offsetParent) === null || _a === void 0 ? void 0 : _a.offsetLeft),
            y: refToElement.current.offsetTop + ((_b = refToElement.current.offsetParent) === null || _b === void 0 ? void 0 : _b.offsetTop) + refToElement.current.offsetHeight
        };
        if (newPopupPosition.x !== ((_c = column.headerFilterPopupPosition) === null || _c === void 0 ? void 0 : _c.x) || newPopupPosition.y !== ((_d = column.headerFilterPopupPosition) === null || _d === void 0 ? void 0 : _d.y)) {
            dispatch((0, actionCreators_1.updatePopupPosition)(newPopupPosition));
        }
    }
};
exports.checkPopupPosition = checkPopupPosition;
